# HiQPdf Client for .NET Core


[![HiQPdf Logo Image](http://github.com/hiqpdf/nuget-readme/blob/main/hiqpdf-banner.png?raw=true)](http://www.hiqpdf.com)

[Multi-Platform PDF Library for .NET Core](http://www.hiqpdf.com/multiplatform-html-to-pdf-library-net-core.aspx) | [HTML to PDF for C#](http://www.hiqpdf.com/multiplatform-html-to-pdf-library-net-core.aspx) | [Free Trial Download](http://www.hiqpdf.com/downloads.aspx) | [Licensing](http://www.hiqpdf.com/purchase.aspx)

HiQPdf Client for .NET Core offers you a modern, simple, fast, flexible and powerful tool to create complex and stylish PDF documents in .NET Core applications with just a few lines of C# code.

HiQPdf client library includes the fastest and the most precise HTML to PDF conversion technology. You can easily design a document in HTML with CSS3, JavaScript, SVG or Canvas and then convert it to PDF preserving the exact content and style.
The library is much more than just a HTML to PDF converter. It is a complete PDF library that you can use to create new PDF documents and edit existing PDF documents, extract text and images from PDF, search text in PDF, rasterize PDF pages to images or convert PDF to HTML.

## Library Features

* **HTML to PDF Converter** to quickly create with very high accuracy PDF documents from HTML documents with advanced support for CSS, JavaScript, Web Fonts and SVG. The converter can automatically create table of contents, bookmarks and internal links from HTML document structure
* **HTML to Image Converter** to take snapshots of web pages and produce raster images in various formats like PNG, JPG, BMP
* **HTML to SVG Converter** to create high quality vector images in SVG  format from HTML
* **PDF to Image Converter** allows you to rasterize PDF document pages to images and produce a separate image for each PDF page or to create a multi-page TIFF image for the entire PDF document
* **PDF to HTML Converter** offers the possibility to create HTML documents from PDF pages and also to produce a index file for the entire document
* **PDF to Text Converter** can extract the text from PDF documents with various options like preserving the original text order or the reading order, marking the page breaks with special characters 
* **Search text in PDF** functionality allows you to search and highlight text in PDF document pages
* **Extract images from PDF** to get the images embedded in PDF documents preserving images transparency
* **Create PDF Documents** in a classic manner laying out PDF objects like text, HTML, SVG, images and graphics to an empty document
* **Security and Digital Signatures** feature allows you create encrypted, password protected, digitally signed PDF documents
* **Interactive Features** like PDF forms, text notes, internal links, JavaScript actions
* **Merge PDF** feature allows you combine multiple PDF documents into a single one
* **Stamp PDF** to apply HTML, text and images content which repeats in each PDF page of a PDF document
 

## Platforms Compatibility

HiQPdf Client Library for .NET Core was built to target the .NET Standard 2.0 and its compatibility list includes:

* .NET Core 7, 6, .NET Standard 2.0 , .NET Framework 4.6.2 and the later versions
* Windows, Linux and MacOS operating systems
* Azure App Service, Azure Functions or any other Azure application for .NET
* Xamarin, Mono and Universal Windows Platform (UWP)
* Any type of Web, Desktop or Console application for .NET


## Start Using HiQPdf

Before using the client library it is necessary to install the HiQPdf Server. The server can run as a Windows Service or as an Azure Cloud Service. The server can be accessed with an IP address and a port number which are assigned when the server is installed. 

### HiQPdf Server Installation

You can [Download HiQPdf Server](http://www.hiqpdf.com/downloads.aspx#server_download) as a ZIP file and extract it in a root folder on your computer.
Follow the detailed instructions from *Installation Guide.pdf* document to install the server and get the server IP address that you will use in the client applications. 
For a quick testing you can install the Windows Service on localhost with default options and in this case the assigned IP address is 127.0.0.1.

After server installation you are ready to use the client library in your .NET Core applications. You can start by copying the C# code below in your application or you can start with our demo application for .NET Core from downloadable product package.

### C# Code Sample for HTML to PDF

The C# code sample below shows how to quickly produce PDF documents from HTML pages or HTML code and save the resulted PDF to a memory buffer or to a PDF file.

At the top of your C# source file you have to add the ```using HiQPdfClient;``` instruction to make available the HiQPdfClient namespace to your application code.

```csharp

// Include the HiQPdfClient namespace at the top of your C# file
using HiQPdfClient;
```

You can use the C# code below to convert a HTML code or a HTML page from a given URL to a PDF file.

```csharp
// Create the HTML to PDF converter object
string server_ip_address = "127.0.0.1";
HtmlToPdf converter = new HtmlToPdf(server_ip_address);

// Convert the HTML code to a PDF file
converter.ConvertHtmlToFile("<b>Hello World</b> from HiQPdf !", null, "html_to_file.pdf");

// Convert the HTML page from URL to a PDF file
string urlToConvert = "http://www.hiqpdf.com";
converter.ConvertUrlToFile(urlToConvert, "url_to_file.pdf");
```

Alternatively you can produce the PDF document in a memory buffer that you can further save to a file on server or you can send for download to browser in ASP.NET applications.

```csharp
// Create the HTML to PDF converter object
string server_ip_address = "127.0.0.1";
HtmlToPdf converter = new HtmlToPdf(server_ip_address);

// Convert the HTML code to memory
byte[] htmlToPdfData = converter.ConvertHtmlToMemory("<b>Hello World</b> from HiQPdf !", null);

// Save the PDF data to a file
System.IO.File.WriteAllBytes("html_to_memory.pdf", htmlToPdfData);

// Convert the HTML page from URL to memory
string urlToConvert = "http://www.hiqpdf.com";
byte[] urlToPdfData = converter.ConvertUrlToMemory(urlToConvert);

// Save the PDF data to a file
System.IO.File.WriteAllBytes("url_to_memory.pdf", urlToPdfData);
```

The C# code below can be used in your ASP.NET Core applications to convert a HTML code to PDF in a memory buffer and then send the PDF data for downlaod to browser.

```csharp
// Create the HTML to PDF converter object
string server_ip_address = "127.0.0.1";
HtmlToPdf converter = new HtmlToPdf(server_ip_address);

// Convert the HTML code to memory
byte[] htmlToPdfData = converter.ConvertHtmlToMemory("<b>Hello World</b> from HiQPdf !", null);

FileResult fileResult = new FileContentResult(htmlToPdfData, "application/pdf");
fileResult.FileDownloadName = "html_to_pdf.pdf";
return fileResult;
```

## Free Trial Download

A free trial package containing the library binaries, an ASP.NET Core demo application with C# code for all library features, the complete product documentation with examples and API reference can be downloaded from [HiQPdf Downloads](http://www.hiqpdf.com/downloads.aspx) web page.

## Licensing

The licensing model is simple and flexible. The licenses are perpetual and there is no limit for the number of machines where you can deploy your applications using the HiQPdf library.
The same license works with regular HiQPdf library for .NET and with the client library for .NET Core.
You can find more details about licensing on [Online Purchase](http://www.hiqpdf.com/purchase.aspx) web page.

## Support

For support and questions please use the email addresses from the [contact](http://www.hiqpdf.com/contact.aspx) web page. 
